diff --git a/src/components/ThreadEnvelope.vue b/src/components/ThreadEnvelope.vue
index 9ec337783742d88f9621e81a9b4bf7ff68fb7893..f8dbb5e1471a46aa7c06dd70287d7880589b724b 100644
--- a/src/components/ThreadEnvelope.vue
+++ b/src/components/ThreadEnvelope.vue
@@ -66,6 +66,7 @@
 				</router-link>
 				<MenuEnvelope class="app-content-list-item-menu"
 					:envelope="envelope"
+					:with-reply="false"
 					:with-select="false"
 					:with-show-source="true" />
 			</div>
diff --git a/src/components/MenuEnvelope.vue b/src/components/MenuEnvelope.vue
index 007401af4abbb3b4adccd9f81532d4984a98f141..3a182fee9a9a9d8870da63e985c61212ce8082f3 100644
--- a/src/components/MenuEnvelope.vue
+++ b/src/components/MenuEnvelope.vue
@@ -5,6 +5,12 @@
 			menu-align="right"
 			event=""
 			@click.native.prevent>
+			<ActionRouter v-if="withReply"
+				:icon="hasMultipleRecipients ? 'icon-reply-all' : 'icon-reply'"
+				:close-after-click="true"
+				:to="hasMultipleRecipients ? replyAllLink : replyOneLink">
+				{{ t('mail', 'Reply') }}
+			</ActionRouter>
 			<ActionRouter v-if="hasMultipleRecipients"
 				icon="icon-reply"
 				:close-after-click="true"
@@ -134,24 +140,35 @@ export default {
 		MoveModal,
 	},
 	props: {
-		envelope: { // The envelope on which this menu will act
+		envelope: {
+			// The envelope on which this menu will act
 			type: Object,
 			required: true,
 		},
-		mailbox: { // It is just used to get the accountId when envelope doesn't have it
+		mailbox: {
+			// It is just used to get the accountId when envelope doesn't have it
 			type: Object,
 			required: false,
 			default: undefined,
 		},
-		isSelected: { // Indicates if the envelope is currently selected
+		isSelected: {
+			// Indicates if the envelope is currently selected
 			type: Boolean,
 			default: false,
 		},
-		withSelect: { // "Select" action should only appear in envelopes from the envelope list
+		withReply: {
+			// "Reply" action should only appear in envelopes from the envelope list
+			// (Because in thread envelopes, this action is already set as primary button of this menu)
+			type: Boolean,
+			default: true,
+		},
+		withSelect: {
+			// "Select" action should only appear in envelopes from the envelope list
 			type: Boolean,
 			default: true,
 		},
-		withShowSource: { // "Show source" action should only appear in thread envelopes
+		withShowSource: {
+			// "Show source" action should only appear in thread envelopes
 			type: Boolean,
 			default: true,
 		},